# -*- encoding: utf-8 -*-
# stub: morning_glory 0.0.3 ruby lib

Gem::Specification.new do |s|
  s.name = "morning_glory".freeze
  s.version = "0.0.3"

  s.required_rubygems_version = Gem::Requirement.new(">= 0".freeze) if s.respond_to? :required_rubygems_version=
  s.require_paths = ["lib".freeze]
  s.authors = ["Adam Burmister".freeze, "Todd Sedano".freeze]
  s.date = "2011-07-21"
  s.description = "http://www.engineyard.com/blog/2010/extending-rails-3-with-railties/\nhttp://www.igvita.com/2010/08/04/rails-3-internals-railtie-creating-plugins/\n\n\nh1. Morning Glory\n\nMorning Glory is comprised of a rake task and helper methods that manages the deployment of static assets into an Amazon CloudFront CDN's S3 Bucket, improving the performance of static assets on your Rails web applications.\n\n_NOTE: You will require an Amazon Web Services (AWS) account in order to use this gem. Specially: S3 for storing the files you wish to distribute, and CloudFront for CDN distribution of those files._     \n\nThis version of Morning Glory works with Rails 3.x and Ruby 1.9.x\n\nh2. What does it do?\n\nMorning Glory provides an easy way to deploy Ruby on Rails application assets to the Amazon CloudFront CDN. \n\nIt solves a number of common issues with S3/CloudFront. For instance, CloudFront won't automatically expire old assets stored on edge nodes when you redeploy new assets (the Cloudfront expiry time is 24 hours minimum). \nTo fix this Morning Glory will automatically namespace asset releases for you, then update all references to those renamed assets within your stylesheets ensuring there are no broken asset links.\n\nIt also provides a helper method to rewrite all standard Rails asset helper generated URLs to your CloudFront CDN distributions, as well as handling switching between HTTP and HTTPS.\n\nMorning Glory was also built with SASS (Syntactically Awesome Stylesheets) in mind. If you use Sass for your stylesheets they will automatically be built before deployment to the CDN. See http://sass-lang.com/ for more information on Sass.s\n\nh2. What it doesn't do\n\nMorning Glory cannot configure your CloudFront distributions for you automatically. You will manually have to login to your AWS Management Console account, \"https://console.aws.amazon.com/cloudfront/home\":https://console.aws.amazon.com/cloudfront/home, and set up a distribution pointing to an S3 Bucket.\n\nh2. Installation\n\n<pre>\ngem 'morning_glory'\n</pre>\n\nh2. Usage\n\nMorning Glory provides it's functionality via rake tasks. You'll need to specify the target rails environment configuration you want to deploy for by using the @RAILS_ENV={env}@ parameter (for example, @RAILS_ENV=production@).\n\n<pre>\nrake morning_glory:cloudfront:deploy RAILS_ENV={YOUR_TARGET_ENVIRONMENT}\n</pre>\n\nh2. Configuration\n\nh3. The Morning Glory configuration file, @config/morning_glory.yml@\n\nYou can specify a configuration section for every rails environment (production, staging, testing, development). This section can have the following properties defined:\n\n<pre>\n--- \nproduction: \n  enabled: true                     # Is MorningGlory enabled for this environment?\n  bucket: cdn.production.foo.com    # The bucket to deploy your assets into\n  s3_logging_enabled: true          # Log the deployment to S3\n  revision: \"20100317134627\"        # The revision prefix. This timestamp automatically generateed on deployment\n  delete_prev_rev: true             # Delete the previous asset release (save on S3 storage space)\n</pre>\n\nh3. The Amazon S3 authentication keys configuration file, @config/s3.yml@\n\nThis file provides the access credentials for your Amazon AWS S3 account.\nYou can configure keys for all your environments (production, staging, testing, development).\n\n<pre>\n---\nproduction:\n  access_key_id: YOUR_ACCESS_KEY\n  secret_access_key: YOUR_SECRET_ACCESS_KEY\n</pre>\n\nNote: If you are deploying your system to Heroku, you can configure your Amazon AWS S3 information with the environment variables S3_KEY and S3_SECRET instead of using a configuration file. \n\nh3. Set up an asset_host\n\nFor each environment that you'd like to utilise the CloudFront CDN for you'll need to define the asset_host within the @config/environments/{ENVIRONMENT}.rb@ configuration file.\n\nAs of June 2010 AWS supports HTTPS requests on the CloudFront CDN, so you no longer have to worry about switching servers. (Yay!)\n\nh4. Example config/environments/production.rb @asset_host@ snippet:\n\nHere we're targeting a CNAME domain with HTTP support.\n\n<pre>\nActionController::Base.asset_host = Proc.new { |source, request|\n  if request.ssl?\n    \"\#{request.protocol}\#{request.host_with_port}\"\n  else\n    \"\#{request.protocol}assets.example.com\"\n  end\n}\n</pre>\n\n\nh3. Why do we have to use a revision-number/namespace/timestamp?\n\nOnce an asset has been deployed to the Amazon Cloudfront edge servers it cannot be modified - the version exists until it expires (minimum of 24 hours).\n\nTo get around this we need to prefix the asset path with a revision of some sort - in MorningGlory's case we use a timestamp. That way you can deploy many times during a 24 hour period and always have your latest revision available on your web site.\n\nh2. Dependencies\n\nh3. AWS S3\n\nRequired for uploading the assets to the Amazon Web Services S3 buckets.\nSee \"http://amazon.rubyforge.org/\":http://amazon.rubyforge.org/ for more documentation on installation.\n\nh2. About the name\n\nPerhaps not what you'd expect; a \"Morning Glory\":http://en.wikipedia.org/wiki/Morning_Glory_cloud is a rare cloud formation observed by glider pilots in Australia (see my side project, \"YourFlightLog.com for flight-logging software for paraglider and hang-glider pilots\":http://www.yourflightlog.com, from which the Morning Glory plugin was originally extracted).\n\nCopyright (c) 2010 \"@AdamBurmister\":http://twitter.com/adamburmister/, released under the MIT license".freeze
  s.email = "professor@gmail.com".freeze
  s.homepage = "https://github.com/professor/morning_glory".freeze
  s.licenses = ["MIT".freeze]
  s.required_ruby_version = Gem::Requirement.new(">= 1.9".freeze)
  s.rubygems_version = "3.2.22".freeze
  s.summary = "Morning Glory is comprised of a rake task and helper methods that manages the deployment of static assets into an Amazon CloudFront CDN\u00E2\u0080\u0099s S3 Bucket, improving the performance of static assets on your Rails web applications.".freeze

  s.installed_by_version = "3.2.22" if s.respond_to? :installed_by_version

  if s.respond_to? :specification_version then
    s.specification_version = 3
  end

  if s.respond_to? :add_runtime_dependency then
    s.add_development_dependency(%q<aws-s3>.freeze, [">= 0"])
    s.add_development_dependency(%q<rails>.freeze, [">= 0"])
    s.add_runtime_dependency(%q<aws-s3>.freeze, [">= 0"])
    s.add_runtime_dependency(%q<rails>.freeze, [">= 0"])
  else
    s.add_dependency(%q<aws-s3>.freeze, [">= 0"])
    s.add_dependency(%q<rails>.freeze, [">= 0"])
    s.add_dependency(%q<aws-s3>.freeze, [">= 0"])
    s.add_dependency(%q<rails>.freeze, [">= 0"])
  end
end
